<?php

/**
* 
* Parses for text which contains a single space at the beginning of the line and transforms it to a preformatted body of text
* 
* @category Text
* 
* @package Text_Wiki
* 
* @author Jay E. Taylor <outtatime@gmail.com>
* @author Paul M. Jones <pmjones@php.net>
*
* @license LGPL
* 
*/

/**
* 
* Parses for text which contains a single space at the beginning of the line
* and transforms it to a preformatted body of text.
* 
* This class implements a Text_Wiki rule to find 1 or more lines in the soure
* which begin with a space, indicating that it is part of a block of
* preformatted text and should be rendered as such.
*
* @category Text
* 
* @package Text_Wiki
* 
* @author Jay E. Taylor <outtatime@gmail.com>
* 
*/

class Text_Wiki_Parse_Preformatted extends Text_Wiki_Parse {
    
    
    /**
    * 
    * The regular expression used to find source text matching this
    * rule.
    * 
    * @access public
    * 
    * @var string
    * 
    */
    
    var $regex = "/(\n (.*([\n][ ]).*)+)|([\n][ ].*)/";
    
    
    /**
    * 
    * this parses the wiki markup for preformatted elements
    * (lines which begin with a space)
    *
    *
    * Generates a token entry for the matched text.  Token options are:
    * 
    * 'text' => The full matched text.
    * 
    * @access public
    *
    * @param array &$matches The array of matches from parse().
    *
    * @return A delimited token number to be used as a placeholder in
    * the source text.
    *
    */
    
    function process(&$matches)
    {
        $return = '';

        // the array of lines which match our regexps criteria,
        // these are what we are going to iterate through
        $lines = explode("\n", $matches[0]);

        // shift the first element off the array since it is always empty
        array_shift($lines);
        
        // make sure we do not have an empty block
        if (count($lines) == 0) {
          // we don't want to do any work if we do
          $return = null;
        } else {
          foreach($lines as $key => $value) {
            $return .= "\n".substr($value, 1, strlen($value) - 1);
          }
        }

        $options = array('text' => $return."\n");
        return $this->wiki->addToken($this->rule, $options);
    }
}
?>
